@@ -5,7 +5,7 @@ use App::Sandy::Base 'class';
 
 extends 'App::Sandy::CLI::App';
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 sub command_map {
 	genome        => 'App::Sandy::Command::Genome',
@@ -29,7 +29,7 @@ App::Sandy - App builder that simulates single-end and paired-end reads.
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,7 @@ version 0.23
 
  Options:
   -h, --help               brief help message
-  -u, --man                full documentation
+  -H, --man                full documentation
 
  Help commands:
   help                     show application or command-specific help
@@ -60,14 +60,14 @@ version 0.23
 
 =head1 DESCRIPTION
 
-B<SANDY> is a bioinformatics tool that provides a simple engine to simulate next-generation
+B<Sandy> is a bioinformatics tool that provides a simple engine to simulate next-generation
 sequencing for genomic and transcriptomic data. Simulated data works as experimental control
-- a key step to optimize NGS analysis - in comparison to hypothetical models. SANDY is a
+- a key step to optimize NGS analysis - in comparison to hypothetical models. B<Sandy> is a
 straightforward, easy-to-use, fast and highly customizable tool that generates reads requiring
-only a FASTA file as input. SANDY can simulate single/paired-end reads from both whole exome
+only a FASTA file as input. B<Sandy> can simulate single/paired-end reads from both whole exome
 sequencing and RNA-seq as if produced from the most used second and third-generation sequencing
-platforms. SANDY’s reads can be simulated with genetic variations such as SNVs, indels and gene
-fusions. For customization purposes, SANDY have built-in (native) databases that can be easily
+platforms. B<Sandy>’s reads can be simulated with genetic variations such as SNVs, indels and gene
+fusions. For customization purposes, B<Sandy> have built-in (native) databases that can be easily
 extended with varying gene/transcript expression profiles, sequencing errors, sequencing
 coverages and genomic variations.
 
@@ -105,13 +105,21 @@ Fernanda Orpinelli <forpinelli@mochsl.org.br>
 
 =item *
 
+Rafael Mercuri <rmercuri@mochsl.org.br>
+
+=item *
+
+Rodrigo Barreiro <rbarreiro@mochsl.org.br>
+
+=item *
+
 Pedro A. F. Galante <pgalante@mochsl.org.br>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Teaching and Research Institute from Sírio-Libanês Hospital.
+This software is Copyright (c) 2023 by Teaching and Research Institute from Sírio-Libanês Hospital.
 
 This is free software, licensed under:
 
