@@ -5,7 +5,7 @@ use App::Sandy::Base 'class';
 
 extends 'App::Sandy::Command::Quality';
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 sub validate_args {
 	my ($self, $args) = @_;
@@ -44,7 +44,7 @@ App::Sandy::Command::Quality::Dump - quality subcommand class. Dump a quality pr
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -55,11 +55,11 @@ version 0.23
 
  Options:
   -h, --help               brief help message
-  -u, --man                full documentation
+  -H, --man                full documentation
 
 =head1 DESCRIPTION
 
-Dump a quality profile from database.
+Dump a quality-profile from database.
 
 =head1 AUTHORS
 
@@ -95,13 +95,21 @@ Fernanda Orpinelli <forpinelli@mochsl.org.br>
 
 =item *
 
+Rafael Mercuri <rmercuri@mochsl.org.br>
+
+=item *
+
+Rodrigo Barreiro <rbarreiro@mochsl.org.br>
+
+=item *
+
 Pedro A. F. Galante <pgalante@mochsl.org.br>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Teaching and Research Institute from Sírio-Libanês Hospital.
+This software is Copyright (c) 2023 by Teaching and Research Institute from Sírio-Libanês Hospital.
 
 This is free software, licensed under:
 
