@@ -5,7 +5,7 @@ use App::Sandy::Base 'class';
 
 extends 'App::Sandy::Command::Variation';
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 sub validate_args {
 	my ($self, $args) = @_;
@@ -23,7 +23,7 @@ sub execute {
 	my ($self, $opts, $args) = @_;
 
 	my $variation = $self->retrievedb($args);
-	print "#seqid\tposition\tid\treference\talteration\tgenotype\n";
+	print "#seqid\tposition\tid\treference\talternate\tgenotype\n";
 
 	for my $id (sort keys %$variation) {
 		my $data = $variation->{$id};
@@ -47,22 +47,22 @@ App::Sandy::Command::Variation::Dump - variation subcommand class. Dump structur
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
- sandy variation dump <structural variation>
+ sandy variation dump <genomic variation>
 
  Arguments:
-  a structural variation entry
+  a genomic-variation entry
 
  Options:
   -h, --help               brief help message
-  -u, --man                full documentation
+  -H, --man                full documentation
 
 =head1 DESCRIPTION
 
-Dump structural variation from database.
+Dump genomic-variation from database.
 
 =head1 AUTHORS
 
@@ -98,13 +98,21 @@ Fernanda Orpinelli <forpinelli@mochsl.org.br>
 
 =item *
 
+Rafael Mercuri <rmercuri@mochsl.org.br>
+
+=item *
+
+Rodrigo Barreiro <rbarreiro@mochsl.org.br>
+
+=item *
+
 Pedro A. F. Galante <pgalante@mochsl.org.br>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Teaching and Research Institute from Sírio-Libanês Hospital.
+This software is Copyright (c) 2023 by Teaching and Research Institute from Sírio-Libanês Hospital.
 
 This is free software, licensed under:
 
