@@ -3,20 +3,20 @@ package App::Sandy::Role::Counter;
 
 use App::Sandy::Base 'role';
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 sub with_make_counter {
 	# ALgorithm based in perlfaq:
 	# How do I select a random line from a file?
 	# "The Art of Computer Programming"
 
-	my ($self, $num, $picks) = @_;
+	my ($self, $num, $picks, $rng) = @_;
 	return sub {
 		state $count_down = $num;
 		state $picks_left = $picks;
 
 		my $rc = 0;
-		my $rand = int(rand($count_down));
+		my $rand = $rng->get_n($count_down);
 
 		if ($rand < $picks_left) {
 			$rc = 1;
@@ -40,7 +40,7 @@ App::Sandy::Role::Counter - Bayes counter
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 AUTHORS
 
@@ -76,13 +76,21 @@ Fernanda Orpinelli <forpinelli@mochsl.org.br>
 
 =item *
 
+Rafael Mercuri <rmercuri@mochsl.org.br>
+
+=item *
+
+Rodrigo Barreiro <rbarreiro@mochsl.org.br>
+
+=item *
+
 Pedro A. F. Galante <pgalante@mochsl.org.br>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Teaching and Research Institute from Sírio-Libanês Hospital.
+This software is Copyright (c) 2023 by Teaching and Research Institute from Sírio-Libanês Hospital.
 
 This is free software, licensed under:
 
